@@ -77,8 +77,9 @@ class ApplicationTags(object):
         return tags
 
     def add_custom_tags_from_env(self, pattern):
-        """Set custom tags from environment variables that match the regex pattern.
+        """Set custom tags from environment variables.
 
+        (that match the regex pattern)
         @param pattern: Regex pattern
         """
         for key in os.environ:
@@ -93,6 +94,7 @@ class ApplicationTags(object):
         @param tag_key: Key of the custom tag
         @param var_name: Key of the environment variable
         """
+        # pylint: disable=broad-exception-raised
         if var_key in os.environ:
             value = os.environ[var_key]
             if value:
